/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2017-2019 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::Function1Types::reverseRamp

Description
    A wrapper class for reversing any ramp function such that a ramp function
    starting from 1 and decreasing linearly to 0 from \c start over the \c
    duration and remaining at 0 thereafter.

See also
    Foam::Function1Types::ramp

    externalForce
    {
        ...
        ramp reverseRamp; // ramp funciton wrapper
        rampType linearRamp; // ramp function to be reversed
        start 1;
        duration 1;
    }
SourceFiles
    reverseRamp.C

\*---------------------------------------------------------------------------*/

#ifndef reverseRamp_H
#define reverseRamp_H

#include "ramp.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{
namespace Function1Types
{

/*---------------------------------------------------------------------------*\
                           Class reverseRamp Declaration
\*---------------------------------------------------------------------------*/

class reverseRamp
:
    public ramp
{

    autoPtr<Function1<scalar>> rampPtr_;

public:

    // Runtime type information
    TypeName("reverseRamp");


    // Constructors

        //- Construct from entry name and dictionary
        reverseRamp
        (
            const word& entryName,
            const dictionary& dict
        );


    //- Destructor
    virtual ~reverseRamp();


    // Member Functions

        //- Return value for time t
        virtual inline scalar value(const scalar t) const;


    // Member Operators

        //- Disallow default bitwise assignment
        void operator=(const reverseRamp&) = delete;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Function1Types
} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "reverseRampI.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
